@@ -7,4 +7,4 @@ import beobench
 
 @pytest.mark.slow
 def test_run_command(run_config):
-    beobench.run(config=run_config, dev_path=".[extended]")
+    beobench.run(config=run_config, dev_path=".")
